/****************************************************************************
** Meta object code from reading C++ file 'linechartpoint.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kqtquickcharts-26.07.90/src/linechartpoint.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'linechartpoint.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14LineChartPointE_t {};
} // unnamed namespace

template <> constexpr inline auto LineChartPoint::qt_create_metaobjectdata<qt_meta_tag_ZN14LineChartPointE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LineChartPoint",
        "lineChartCoreChanged",
        "",
        "backgroundPainterChanged",
        "dimensionChanged",
        "rowChanged",
        "textChanged",
        "maxYChanged",
        "triggerUpdate",
        "lineChartCore",
        "LineChartCore*",
        "backgroundPainter",
        "LineChartBackgroundPainter*",
        "dimension",
        "row",
        "text"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lineChartCoreChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundPainterChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dimensionChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rowChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxYChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'triggerUpdate'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lineChartCore'
        QtMocHelpers::PropertyData<LineChartCore*>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'backgroundPainter'
        QtMocHelpers::PropertyData<LineChartBackgroundPainter*>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'dimension'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'row'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LineChartPoint, qt_meta_tag_ZN14LineChartPointE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LineChartPoint::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPaintedItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LineChartPointE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LineChartPointE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14LineChartPointE_t>.metaTypes,
    nullptr
} };

void LineChartPoint::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LineChartPoint *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lineChartCoreChanged(); break;
        case 1: _t->backgroundPainterChanged(); break;
        case 2: _t->dimensionChanged(); break;
        case 3: _t->rowChanged(); break;
        case 4: _t->textChanged(); break;
        case 5: _t->maxYChanged(); break;
        case 6: _t->triggerUpdate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LineChartPoint::*)()>(_a, &LineChartPoint::lineChartCoreChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LineChartPoint::*)()>(_a, &LineChartPoint::backgroundPainterChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LineChartPoint::*)()>(_a, &LineChartPoint::dimensionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LineChartPoint::*)()>(_a, &LineChartPoint::rowChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LineChartPoint::*)()>(_a, &LineChartPoint::textChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LineChartPoint::*)()>(_a, &LineChartPoint::maxYChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<LineChartCore**>(_v) = _t->lineChartCore(); break;
        case 1: *reinterpret_cast<LineChartBackgroundPainter**>(_v) = _t->backgroundPainter(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->dimension(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->row(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLineChartCore(*reinterpret_cast<LineChartCore**>(_v)); break;
        case 1: _t->setBackgroundPainter(*reinterpret_cast<LineChartBackgroundPainter**>(_v)); break;
        case 2: _t->setDimension(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setRow(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LineChartPoint::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LineChartPoint::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LineChartPointE_t>.strings))
        return static_cast<void*>(this);
    return QQuickPaintedItem::qt_metacast(_clname);
}

int LineChartPoint::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void LineChartPoint::lineChartCoreChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LineChartPoint::backgroundPainterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LineChartPoint::dimensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LineChartPoint::rowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LineChartPoint::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LineChartPoint::maxYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
