/****************************************************************************
** Meta object code from reading C++ file 'xychartcore.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kqtquickcharts-26.07.90/src/xychartcore.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xychartcore.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11XYChartCoreE_t {};
} // unnamed namespace

template <> constexpr inline auto XYChartCore::qt_create_metaobjectdata<qt_meta_tag_ZN11XYChartCoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XYChartCore",
        "pointRadiusChanged",
        "",
        "lineWidthChanged",
        "xAxisChanged",
        "yAxisChanged",
        "textColorChanged",
        "fontChanged",
        "gridLinesChanged",
        "axisLabelCountGoalChanged",
        "updateAxis",
        "pointRadius",
        "lineWidth",
        "xAxis",
        "Dimension*",
        "yAxis",
        "textColor",
        "QColor",
        "font",
        "QFont",
        "gridLines",
        "axisLabelCountGoal"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pointRadiusChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineWidthChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xAxisChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yAxisChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textColorChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gridLinesChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'axisLabelCountGoalChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAxis'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pointRadius'
        QtMocHelpers::PropertyData<qreal>(11, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'lineWidth'
        QtMocHelpers::PropertyData<qreal>(12, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'xAxis'
        QtMocHelpers::PropertyData<Dimension*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'yAxis'
        QtMocHelpers::PropertyData<Dimension*>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'font'
        QtMocHelpers::PropertyData<QFont>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'gridLines'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'axisLabelCountGoal'
        QtMocHelpers::PropertyData<uint>(21, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XYChartCore, qt_meta_tag_ZN11XYChartCoreE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XYChartCore::staticMetaObject = { {
    QMetaObject::SuperData::link<ChartCore::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11XYChartCoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11XYChartCoreE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11XYChartCoreE_t>.metaTypes,
    nullptr
} };

void XYChartCore::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XYChartCore *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pointRadiusChanged(); break;
        case 1: _t->lineWidthChanged(); break;
        case 2: _t->xAxisChanged(); break;
        case 3: _t->yAxisChanged(); break;
        case 4: _t->textColorChanged(); break;
        case 5: _t->fontChanged(); break;
        case 6: _t->gridLinesChanged(); break;
        case 7: _t->axisLabelCountGoalChanged(); break;
        case 8: _t->updateAxis(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XYChartCore::*)()>(_a, &XYChartCore::pointRadiusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYChartCore::*)()>(_a, &XYChartCore::lineWidthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYChartCore::*)()>(_a, &XYChartCore::xAxisChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYChartCore::*)()>(_a, &XYChartCore::yAxisChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYChartCore::*)()>(_a, &XYChartCore::textColorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYChartCore::*)()>(_a, &XYChartCore::fontChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYChartCore::*)()>(_a, &XYChartCore::gridLinesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (XYChartCore::*)()>(_a, &XYChartCore::axisLabelCountGoalChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Dimension* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->pointRadius(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->lineWidth(); break;
        case 2: *reinterpret_cast<Dimension**>(_v) = _t->xAxis(); break;
        case 3: *reinterpret_cast<Dimension**>(_v) = _t->yAxis(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->textColor(); break;
        case 5: *reinterpret_cast<QFont*>(_v) = _t->font(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->gridLines(); break;
        case 7: *reinterpret_cast<uint*>(_v) = _t->axisLabelCountGoal(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPointRadius(*reinterpret_cast<qreal*>(_v)); break;
        case 1: _t->setLineWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setXAxis(*reinterpret_cast<Dimension**>(_v)); break;
        case 3: _t->setYAxis(*reinterpret_cast<Dimension**>(_v)); break;
        case 4: _t->setTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setFont(*reinterpret_cast<QFont*>(_v)); break;
        case 6: _t->setGridLines(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setAxisLabelCountGoal(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *XYChartCore::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XYChartCore::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11XYChartCoreE_t>.strings))
        return static_cast<void*>(this);
    return ChartCore::qt_metacast(_clname);
}

int XYChartCore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChartCore::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void XYChartCore::pointRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void XYChartCore::lineWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void XYChartCore::xAxisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void XYChartCore::yAxisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void XYChartCore::textColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void XYChartCore::fontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void XYChartCore::gridLinesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void XYChartCore::axisLabelCountGoalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
