/****************************************************************************
** Meta object code from reading C++ file 'dimension.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kqtquickcharts-26.07.90/src/dimension.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dimension.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DimensionE_t {};
} // unnamed namespace

template <> constexpr inline auto Dimension::qt_create_metaobjectdata<qt_meta_tag_ZN9DimensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dimension",
        "colorChanged",
        "",
        "dataColumnChanged",
        "minimumValueChanged",
        "maximumValueChanged",
        "labelChanged",
        "precisionChanged",
        "unitChanged",
        "unitFactorChanged",
        "updated",
        "markerStyleChanged",
        "lineStyleChanged",
        "formatValue",
        "value",
        "color",
        "QColor",
        "dataColumn",
        "minimumValue",
        "maximumValue",
        "label",
        "precision",
        "unit",
        "unitFactor",
        "markerStyle",
        "MarkerStyle",
        "lineStyle",
        "LineStyle",
        "MarkerStyleNone",
        "MarkerStyleRound",
        "MarkerStyleCross",
        "LineStyleNone",
        "LineStyleSolid",
        "LineStyleDash"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataColumnChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumValueChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumValueChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'precisionChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unitChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unitFactorChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'markerStyleChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineStyleChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'formatValue'
        QtMocHelpers::MethodData<QString(qreal)>(13, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QReal, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'dataColumn'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'minimumValue'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'maximumValue'
        QtMocHelpers::PropertyData<qreal>(19, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'label'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'precision'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'unit'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'unitFactor'
        QtMocHelpers::PropertyData<qreal>(23, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'markerStyle'
        QtMocHelpers::PropertyData<enum MarkerStyle>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'lineStyle'
        QtMocHelpers::PropertyData<enum LineStyle>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MarkerStyle'
        QtMocHelpers::EnumData<enum MarkerStyle>(25, 25, QMC::EnumFlags{}).add({
            {   28, MarkerStyle::MarkerStyleNone },
            {   29, MarkerStyle::MarkerStyleRound },
            {   30, MarkerStyle::MarkerStyleCross },
        }),
        // enum 'LineStyle'
        QtMocHelpers::EnumData<enum LineStyle>(27, 27, QMC::EnumFlags{}).add({
            {   31, LineStyle::LineStyleNone },
            {   32, LineStyle::LineStyleSolid },
            {   33, LineStyle::LineStyleDash },
        }),
    };
    return QtMocHelpers::metaObjectData<Dimension, qt_meta_tag_ZN9DimensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dimension::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DimensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DimensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DimensionE_t>.metaTypes,
    nullptr
} };

void Dimension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Dimension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorChanged(); break;
        case 1: _t->dataColumnChanged(); break;
        case 2: _t->minimumValueChanged(); break;
        case 3: _t->maximumValueChanged(); break;
        case 4: _t->labelChanged(); break;
        case 5: _t->precisionChanged(); break;
        case 6: _t->unitChanged(); break;
        case 7: _t->unitFactorChanged(); break;
        case 8: _t->updated(); break;
        case 9: _t->markerStyleChanged(); break;
        case 10: _t->lineStyleChanged(); break;
        case 11: { QString _r = _t->formatValue((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::colorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::dataColumnChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::minimumValueChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::maximumValueChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::labelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::precisionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::unitChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::unitFactorChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::updated, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::markerStyleChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Dimension::*)()>(_a, &Dimension::lineStyleChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->dataColumn(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->minimumValue(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->maximumValue(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->precision(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->unit(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->unitFactor(); break;
        case 8: *reinterpret_cast<enum MarkerStyle*>(_v) = _t->markerStyle(); break;
        case 9: *reinterpret_cast<enum LineStyle*>(_v) = _t->lineStyle(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 1: _t->setDataColumn(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setMinimumValue(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setMaximumValue(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setLabel(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setPrecision(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setUnit(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setUnitFactor(*reinterpret_cast<qreal*>(_v)); break;
        case 8: _t->setMarkerStyle(*reinterpret_cast<enum MarkerStyle*>(_v)); break;
        case 9: _t->setLineStyle(*reinterpret_cast<enum LineStyle*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dimension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dimension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DimensionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Dimension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Dimension::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dimension::dataColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dimension::minimumValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dimension::maximumValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dimension::labelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dimension::precisionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dimension::unitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dimension::unitFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dimension::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Dimension::markerStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Dimension::lineStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
